
# overgang -- Transition probability estimation

The overgang package includes the Duration Method to estimate 
the transitions probability matrix (stochastic matrix).


### Installation

It's a pip package at https://pypi.org/project/overgang/
```
pip install overgang
```


### Examples
Check the [examples](examples) folder for notebooks.
